@@ -22,18 +22,18 @@ class Driver(unittest.TestCase):
         driver = return_driver()
         cdp_listener = cdp_listener(driver=driver)
         cdp_listener.specify_headers({"sec-ch-ua-platform": my_platform})
-        thread = cdp_listener.start_threaded(listeners={
-            "continue": {"listener": cdp_listener.all_requests, "at_event": cdp_listener.modify_headers},
-        })
+        thread = cdp_listener.start_threaded(listener={"listener": cdp_listener.requests, "at_event": cdp_listener.modify_headers})
 
         driver.get('https://modheader.com/headers?product=ModHeader')
-        time.sleep(3)
+        time.sleep(4)
         driver.refresh()
+        driver.get('https://modheader.com/headers?product=ModHeader')
+        time.sleep(2)
+        platform = driver.find_element(By.XPATH,
+                                       '/html/body/div[1]/main/div[1]/div/div/div/table[1]/tbody/tr[19]/td[2]').accessible_name
+
         time.sleep(1)
-        platform = driver.find_element(By.XPATH, '/html/body/div[1]/main/div[1]/div/div/div/table[1]/tbody/tr[19]/td[2]').accessible_name
-
-        driver.quit()
-
+        cdp_listener.terminate_all()
         self.assertEqual(platform, my_platform)  # add assertion here
 
 
